import time

import jwt
from jwt import ExpiredSignatureError

from app.configs.config import JWT_SECRET, JWT_EXPIRY

headers = {
    "alg": "HS256",
    "typ": "JWT"
}


def generate_jwt(user_id):
    """
    生成jwt
    :param user_id: 用户id
    :return: jwt
    """
    payload = {
        'user_id': user_id,
        'exp': int(time.time() + JWT_EXPIRY)
    }

    token = jwt.encode(payload, JWT_SECRET, algorithm='HS256', headers=headers)
    return token


def verify_jwt(token):
    """
    检验jwt
    :param token: jwt
    :return: dict: payload
    """

    try:
        payload = jwt.decode(token, JWT_SECRET, algorithm=['HS256'], headers=headers)
    except ExpiredSignatureError:
        payload = None

    return payload
